@@ -8,9 +8,9 @@ use v5.16;
 use warnings;
 
 use Carp          qw( croak );
-use Cwd qw( cwd );
 use Exporter 5.57 qw( import );
-use File::Find;
+use ExtUtils::Manifest 1.68 qw( manifind maniread maniskip );
+use File::Basename qw( basename );
 use File::Spec;
 use IO            qw( File );
 use List::Util    qw( first );
@@ -20,7 +20,7 @@ use Test2::API 1.302200 qw( context );
 
 our @EXPORT_OK = qw( all_perl_files_scripts_ok file_scripts_ok );
 
-our $VERSION = 'v0.4.0';
+our $VERSION = 'v0.5.0';
 
 
 sub file_scripts_ok {
@@ -113,7 +113,7 @@ sub _make_negative_regex {
 }
 
 
-# This code is based on code from Test::EOL v2.02, originally by Tomas Doran <bobtfish@bobtfish.net>
+# This code is originally based on code from Test::EOL v2.02, originally by Tomas Doran <bobtfish@bobtfish.net>
 
 sub all_perl_files_scripts_ok {
     my $options = { };
@@ -126,46 +126,37 @@ sub all_perl_files_scripts_ok {
 
 sub _all_perl_files {
     my @files = _all_files(@_);
-    return grep { _is_perl_module($_) || _is_perl_script($_) || _is_pod_file($_) || _is_xs_file($_) } @files;
+    return grep { _is_perl_module($_) || _is_perl_script($_) || _is_pod_file($_) || _is_xs_file($_) || _is_template($_) } @files;
 }
 
 sub _all_files {
-    my $options = { };
+    my $options = {};
     $options = shift if ref $_[0] eq 'HASH';
-    my @base_dirs = @_ ? @_ : cwd();
-    my @found;
-    my $want_sub = sub {
-        my @chunks = ( '', File::Spec->splitdir($File::Find::name) );
-        return $File::Find::prune = 1
-          if -d $File::Find::name
-          and (
-            $chunks[-1] eq 'CVS'                                            # cvs
-            or $chunks[-1] eq '.svn'                                        # subversion
-            or $chunks[-1] eq '.git'                                        # git
-            or $chunks[-1] eq '.build'                                      # Dist::Zilla
-            or $chunks[-1] eq '.mite'                                       # Mite
-            or ( $chunks[-2] eq 'blib' and $chunks[-1] eq 'libdoc' )        # pod doc
-            or ( $chunks[-2] eq 'blib' and $chunks[-1] =~ /^man[0-9]$/ )    # pod doc
-            or $chunks[-1] eq 'local'                                       # Carton
-            or $chunks[-1] eq 'inc'                                         # Module::Install
-            or $chunks[-1] eq 'tmp'                                         # tmp
-          );
-        return if $chunks[-1] eq 'Build';                                   # autogenerated Build script
-        return unless ( -f $File::Find::name && -r _ );
-        shift @chunks;
-        push @found, File::Spec->catfile(@chunks);
+
+    my $mfile = $ExtUtils::Manifest::MANIFEST;
+
+    my $skip  = maniskip;
+    my $found = -e $mfile ? maniread($mfile) : manifind();
+
+    my $check = sub {
+        my ($file) = @_;
+        my $name = basename($file);
+        return
+          if $file =~ m{^CVS/}
+          || $file =~ m{^\.\w+/}                  # .git, .svn, .build, .mite ...
+          || $file =~ m{^blib/}                   #
+          || $file =~ m{^local/}                  # Carton
+          || $file =~ m{^inc/}                    # Module::Install
+          || $name =~ m{^\.}                      #
+          || $name =~ m{~$}
+          || $name =~ m{^#.*#$}                   #
+          || $name =~ m{\.(?:old|bak|backup)$}i
+          || $name eq "Build";
+        return 1;
     };
-    find(
-        {
-            untaint         => 1,
-            untaint_pattern => qr|^([-+@\w./:\\]+)$|,
-            untaint_skip    => 1,
-            wanted          => $want_sub,
-            no_chdir        => 1,
-        },
-        @base_dirs
-    );
-    return File::Spec->no_upwards(@found);
+
+    my @files = grep { !$skip->($_) && $check->($_) } sort keys %{$found};
+    return File::Spec->no_upwards(@files);
 }
 
 sub _is_perl_module {
@@ -177,12 +168,16 @@ sub _is_pod_file {
 }
 
 sub _is_perl_script {
-    my $file = shift;
-    return 1 if $file =~ /\.pl$/i;
-    return 1 if $file =~ /\.t$/;
+    my ($file) = @_;
+    my $name = basename($file);
+    return 1 if $name =~ /\.pl$/i;
+    return 1 if $name =~ /\.t$/;
+    return 1 if $name =~ /\.psgi$/;
+    return 1 if $name =~ /^(?:Rexfile|cpanfile)$/;
     my $fh = IO::File->new( $file, "r" ) or return;
     my $first = $fh->getline;
     return 1 if defined $first && ( $first =~ /^#!.*perl\b/ );
+    return 1 if $file =~ /[.]bat$/i && $first =~ /--[*]-Perl-[*]--/;
     return;
 }
 
@@ -190,6 +185,12 @@ sub _is_xs_file {
     $_[0] =~ /\.(c|h|xs)$/i;
 }
 
+sub _is_template {
+    my ($file) = @_;
+    my $name = basename($file);
+    return 1 if $name =~ /\.(?:epl?|inc|mc|psp|tal|tm?pl|tt)$/;
+}
+
 1;
 
 __END__
@@ -204,7 +205,7 @@ Test::MixedScripts - test text for mixed and potentially confusable Unicode scri
 
 =head1 VERSION
 
-version v0.4.0
+version v0.5.0
 
 =head1 SYNOPSIS
 
@@ -282,9 +283,10 @@ When tests fail, the diagnostic message will indicate the unexpected script and
 
   all_perl_files_scripts_ok();
 
-  all_perl_files_scripts_ok( \%options, @dirs );
+  all_perl_files_scripts_ok( \%options );
 
-This applies L</file_scripts_ok> to all of the Perl scripts in C<@dirs>, or the current directory if they are omitted.
+This applies L</file_scripts_ok> to all of the Perl scripts in the current directory, based the distribution
+L<MANIFEST|ExtUtils::Manifest>.
 
 =head1 KNOWN ISSUES
 
